#[non_exhaustive]pub enum NeedsApproval {
Never,
Always,
Dynamic(ApprovalFn),
}Expand description
Tool-level approval declaration. Call-level approval policies configured on the generation take precedence over it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Never
Never ask.
Always
Always ask.
Dynamic(ApprovalFn)
Ask when the function returns true for the validated input.
Implementations
Sourceimpl NeedsApproval
impl NeedsApproval
Sourcepub async fn resolve(&self, input: JsonValue, ctx: ToolContext) -> bool
pub async fn resolve(&self, input: JsonValue, ctx: ToolContext) -> bool
Resolves the declaration for one call.
Sourcepub fn is_declared(&self) -> bool
pub fn is_declared(&self) -> bool
Returns true unless the declaration is NeedsApproval::Never.