ToolKind

Enum ToolKind 

#[non_exhaustive]
pub enum ToolKind { Function, Dynamic, ProviderDefined { id: String, args: JsonObject, }, ProviderExecuted { id: String, args: JsonObject, supports_deferred_results: bool, }, }
Who defines and who executes a tool.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Function

Application-defined schema, executed by the application (with an execute function) or by the caller (without one).



Dynamic

Defined at runtime (MCP and similar); input and output are untyped.



ProviderDefined

Schema defined by the provider, executed by the application.

Fields

id: String

Provider tool id in <provider>.<tool> form.

args: JsonObject

Provider-specific configuration.



ProviderExecuted

Defined and executed by the provider.

Fields

id: String

Provider tool id in <provider>.<tool> form.

args: JsonObject

Provider-specific configuration.

supports_deferred_results: bool

The result may arrive in a later turn than the call.

Implementations

Source

impl ToolKind

pub fn is_provider(&self) -> bool

Returns true for provider-defined and provider-executed tools.

pub fn is_provider_executed(&self) -> bool

Returns true when the provider executes the tool.

pub fn is_dynamic(&self) -> bool

Returns true for dynamic tools.

pub fn provider_id(&self) -> Option<&str>

The provider tool id, for provider tools.