pub type ToModelOutputFn = Arc<dyn Fn(ModelOutputArgs<'_>) -> ToolResultOutput + Send + Sync>;Expand description
Converts an execution output into what the model receives.
Aliased Type
pub struct ToModelOutputFn { /* private fields */ }pub type ToModelOutputFn = Arc<dyn Fn(ModelOutputArgs<'_>) -> ToolResultOutput + Send + Sync>;Converts an execution output into what the model receives.
pub struct ToModelOutputFn { /* private fields */ }