pub struct LocalProcessSandbox { /* private fields */ }Expand description
A Sandbox backed by the local file system and shell.
Provides no isolation. Paths resolve relative to root, but absolute
paths and .. are not blocked. Use only in tests and examples.
Implementations
Sourceimpl LocalProcessSandbox
impl LocalProcessSandbox
Sourcepub fn new(root: impl Into<PathBuf>) -> Self
pub fn new(root: impl Into<PathBuf>) -> Self
Uses root as the working directory and the platform shell
(/bin/sh -c or cmd /C).
Sourcepub fn with_shell(
self,
program: impl Into<String>,
args: impl IntoIterator<Item = String>,
) -> Self
pub fn with_shell( self, program: impl Into<String>, args: impl IntoIterator<Item = String>, ) -> Self
Overrides the shell used to run commands (program followed by the arguments that precede the command line).
Sourcepub fn with_description(self, description: impl Into<String>) -> Self
pub fn with_description(self, description: impl Into<String>) -> Self
Overrides the description.